==========================
Oslo Configuration Library
==========================

.. image:: https://pypip.in/version/oslo.config/badge.svg
    :target: https://pypi.python.org/pypi/oslo.config/
    :alt: Latest Version

.. image:: https://pypip.in/download/oslo.config/badge.svg?period=month
    :target: https://pypi.python.org/pypi/oslo.config/
    :alt: Downloads

The Oslo configuration API supports parsing command line arguments and
.ini style configuration files.

* License: Apache License, Version 2.0
* Documentation: http://docs.openstack.org/developer/oslo.config
* Source: http://git.openstack.org/cgit/openstack/oslo.config
* Bugs: http://bugs.launchpad.net/oslo.config
